==> xmc4200-0.5.0.crate: xmc4200-0.5.0/src/posif0/pruns.rs <==
#[doc = "Register `PRUNS` writer"]
pub struct W(crate::W<PRUNS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<PRUNS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<PRUNS_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<PRUNS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SRB` writer - Set Run bit"]
pub struct SRB_W<'a> {
    w: &'a mut W,
}
impl<'a> SRB_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
impl W {
    #[doc = "Bit 0 - Set Run bit"]
    #[inline(always)]
    pub fn srb(&mut self) -> SRB_W {
        SRB_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Service Request Processing Run Bit Set\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pruns](index.html) module"]
pub struct PRUNS_SPEC;
impl crate::RegisterSpec for PRUNS_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [pruns::W](W) writer structure"]
impl crate::Writable for PRUNS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets PRUNS to value 0"]
impl crate::Resettable for PRUNS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> xmc4500-0.5.0.crate: xmc4500-0.5.0/src/posif0/pruns.rs <==
#[doc = "Register `PRUNS` writer"]
pub struct W(crate::W<PRUNS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<PRUNS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<PRUNS_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<PRUNS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SRB` writer - Set Run bit"]
pub struct SRB_W<'a> {
    w: &'a mut W,
}
impl<'a> SRB_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
impl W {
    #[doc = "Bit 0 - Set Run bit"]
    #[inline(always)]
    pub fn srb(&mut self) -> SRB_W {
        SRB_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "POSIF Run Bit Set\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pruns](index.html) module"]
pub struct PRUNS_SPEC;
impl crate::RegisterSpec for PRUNS_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [pruns::W](W) writer structure"]
impl crate::Writable for PRUNS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets PRUNS to value 0"]
impl crate::Resettable for PRUNS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
